@@ -18,13 +18,8 @@ function fixman {
 		exit 1
 	fi
 
-	if ! mv -f $1.$ext $2.$ext; then
-		echo fixman: can not mv $1.$ext to $2.$ext
-		exit 1
-	fi
-
-	local base=$2
-	shift 2
+	local base=$1
+	shift 1
 
 	for f in $*; do
 		if ! ln -sf $base.$ext $f.$ext; then
@@ -34,5 +29,8 @@ function fixman {
 }
 
 fixman dialog tk_dialog
-fixman lbSingSel tk_listboxSingleSelect
+fixman focusNext tk_focusNext tk_focusPrev tk_focusFollowsMouse
 fixman menubar tk_menuBar tk_bindForTraversal
+fixman optionMenu tk_optionMenu
+fixman popup tk_popup
+fixman tkvars tk_library tk_patchLevel tkPriv tk_strictMotif tk_version
