@@ -2,12 +2,8 @@
 #
 # This demonstration script creates a toplevel window that displays
 # all of Tk's built-in bitmaps.
-
-if {![info exists widgetDemo]} {
-    error "This script should be run from the \"widget\" demo."
-}
-
-package require tk
+#
+# @(#) bitmap.tcl 1.1 95/05/26 15:56:25
 
 # bitmapRow --
 # Create a row of bitmap items in a window.
@@ -33,6 +29,7 @@ proc bitmapRow {w args} {
 }
 
 set w .bitmap
+global tk_library
 catch {destroy $w}
 toplevel $w
 wm title $w "Bitmap Demonstration"
@@ -42,11 +39,13 @@ positionWindow $w
 label $w.msg -font $font -wraplength 4i -justify left -text "This window displays all of Tk's built-in bitmaps, along with the names you can use for them in Tcl scripts."
 pack $w.msg -side top
 
-## See Code / Dismiss buttons
-set btns [addSeeDismiss $w.buttons $w]
-pack $btns -side bottom -fill x
+frame $w.buttons
+pack  $w.buttons -side bottom -expand y -fill x -pady 2m
+button $w.buttons.dismiss -text Dismiss -command "destroy $w"
+button $w.buttons.code -text "See Code" -command "showCode $w"
+pack $w.buttons.dismiss $w.buttons.code -side left -expand 1
 
 frame $w.frame
-bitmapRow $w.frame.0 error gray12 gray25 gray50 gray75
-bitmapRow $w.frame.1 hourglass info question questhead warning
+bitmapRow $w.frame.0 error gray25 gray50 hourglass
+bitmapRow $w.frame.1 info question questhead warning
 pack $w.frame -side top -expand yes -fill both
