@@ -3,12 +3,8 @@
 # This demonstration script creates a listbox widget that displays
 # many of the colors from the X color database.  You can click on
 # a color to change the application's palette.
-
-if {![info exists widgetDemo]} {
-    error "This script should be run from the \"widget\" demo."
-}
-
-package require tk
+#
+# @(#) colors.tcl 1.1 95/05/26 15:56:27
 
 set w .colors
 catch {destroy $w}
@@ -20,19 +16,21 @@ positionWindow $w
 label $w.msg -font $font -wraplength 4i -justify left -text "A listbox containing several color names is displayed below, along with a scrollbar.  You can scan the list either using the scrollbar or by dragging in the listbox window with button 2 pressed.  If you double-click button 1 on a color, then the application's color palette will be set to match that color"
 pack $w.msg -side top
 
-## See Code / Dismiss buttons
-set btns [addSeeDismiss $w.buttons $w]
-pack $btns -side bottom -fill x
+frame $w.buttons
+pack  $w.buttons -side bottom -expand y -fill x -pady 2m
+button $w.buttons.dismiss -text Dismiss -command "destroy $w"
+button $w.buttons.code -text "See Code" -command "showCode $w"
+pack $w.buttons.dismiss $w.buttons.code -side left -expand 1
 
-frame $w.frame -borderwidth 7.5p
+frame $w.frame -borderwidth 10
 pack $w.frame -side top -expand yes -fill y
 
-ttk::scrollbar $w.frame.scroll -command "$w.frame.list yview"
+scrollbar $w.frame.scroll -command "$w.frame.list yview"
 listbox $w.frame.list -yscroll "$w.frame.scroll set" \
 	-width 20 -height 16 -setgrid 1
 pack $w.frame.list $w.frame.scroll -side left -fill y -expand 1
 
-bind $w.frame.list <Double-Button-1> {
+bind $w.frame.list <Double-1> {
     tk_setPalette [selection get]
 }
 $w.frame.list insert 0 gray60 gray70 gray80 gray85 gray90 gray95 \
