@@ -2,10 +2,8 @@
 #
 # This demonstration script creates a toplevel window containing
 # several label widgets.
-
-if {![info exists widgetDemo]} {
-    error "This script should be run from the \"widget\" demo."
-}
+#
+# @(#) label.tcl 1.1 95/05/26 15:56:33
 
 set w .label
 catch {destroy $w}
@@ -18,7 +16,7 @@ label $w.msg -font $font -wraplength 4i -justify left -text "Five labels are dis
 pack $w.msg -side top
 
 frame $w.buttons
-pack $w.buttons -side bottom -fill x -pady 2m
+pack  $w.buttons -side bottom -expand y -fill x -pady 2m
 button $w.buttons.dismiss -text Dismiss -command "destroy $w"
 button $w.buttons.code -text "See Code" -command "showCode $w"
 pack $w.buttons.dismiss $w.buttons.code -side left -expand 1
@@ -32,7 +30,7 @@ label $w.left.l2 -text "Second label, raised" -relief raised
 label $w.left.l3 -text "Third label, sunken" -relief sunken
 pack $w.left.l1 $w.left.l2 $w.left.l3 -side top -expand yes -pady 2 -anchor w
 
-label $w.right.bitmap -borderwidth 2 -relief sunken \
-	-bitmap @[file join $tk_library demos images face.bmp]
+label $w.right.bitmap -bitmap @$tk_library/demos/images/face \
+	-borderwidth 2 -relief sunken
 label $w.right.caption -text "Tcl/Tk Proprietor"
 pack $w.right.bitmap $w.right.caption -side top
