@@ -3,15 +3,16 @@
 # This file defines the default bindings for Tk listbox widgets
 # and provides procedures that help in implementing those bindings.
 #
-# Copyright © 1994 The Regents of the University of California.
-# Copyright © 1994-1995 Sun Microsystems, Inc.
-# Copyright © 1998 Scriptics Corporation.
+# @(#) listbox.tcl 1.14 95/11/02 11:02:19
+#
+# Copyright (c) 1994 The Regents of the University of California.
+# Copyright (c) 1994-1995 Sun Microsystems, Inc.
 #
 # See the file "license.terms" for information on usage and redistribution
 # of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 
 #--------------------------------------------------------------------------
-# tk::Priv elements used in this file:
+# tkPriv elements used in this file:
 #
 # afterId -		Token returned by "after" for autoscanning.
 # listboxPrev -		The last element to be selected or deselected
@@ -31,9 +32,9 @@
 # can put "break"s in their bindings to avoid the error, but this check
 # makes that unnecessary.
 
-bind Listbox <Button-1> {
-    if {[winfo exists %W]} {
-	tk::ListboxBeginSelect %W [%W index @%x,%y] 1
+bind Listbox <1> {
+    if [winfo exists %W] {
+	tkListboxBeginSelect %W [%W index @%x,%y]
     }
 }
 
@@ -41,56 +42,56 @@ bind Listbox <Button-1> {
 # Among other things, this prevents errors if the user deletes the
 # listbox on a double click.
 
-bind Listbox <Double-Button-1> {
+bind Listbox <2> {
     # Empty script
 }
 
 bind Listbox <B1-Motion> {
-    set tk::Priv(x) %x
-    set tk::Priv(y) %y
-    tk::ListboxMotion %W [%W index @%x,%y]
+    set tkPriv(x) %x
+    set tkPriv(y) %y
+    tkListboxMotion %W [%W index @%x,%y]
 }
 bind Listbox <ButtonRelease-1> {
-    tk::CancelRepeat
+    tkCancelRepeat
     %W activate @%x,%y
 }
-bind Listbox <Shift-Button-1> {
-    tk::ListboxBeginExtend %W [%W index @%x,%y]
+bind Listbox <Shift-1> {
+    tkListboxBeginExtend %W [%W index @%x,%y]
 }
-bind Listbox <Control-Button-1> {
-    tk::ListboxBeginToggle %W [%W index @%x,%y]
+bind Listbox <Control-1> {
+    tkListboxBeginToggle %W [%W index @%x,%y]
 }
 bind Listbox <B1-Leave> {
-    set tk::Priv(x) %x
-    set tk::Priv(y) %y
-    tk::ListboxAutoScan %W
+    set tkPriv(x) %x
+    set tkPriv(y) %y
+    tkListboxAutoScan %W
 }
 bind Listbox <B1-Enter> {
-    tk::CancelRepeat
+    tkCancelRepeat
 }
 
-bind Listbox <<PrevLine>> {
-    tk::ListboxUpDown %W -1
+bind Listbox <Up> {
+    tkListboxUpDown %W -1
 }
-bind Listbox <<SelectPrevLine>> {
-    tk::ListboxExtendUpDown %W -1
+bind Listbox <Shift-Up> {
+    tkListboxExtendUpDown %W -1
 }
-bind Listbox <<NextLine>> {
-    tk::ListboxUpDown %W 1
+bind Listbox <Down> {
+    tkListboxUpDown %W 1
 }
-bind Listbox <<SelectNextLine>> {
-    tk::ListboxExtendUpDown %W 1
+bind Listbox <Shift-Down> {
+    tkListboxExtendUpDown %W 1
 }
-bind Listbox <<PrevChar>> {
+bind Listbox <Left> {
     %W xview scroll -1 units
 }
-bind Listbox <<PrevWord>> {
+bind Listbox <Control-Left> {
     %W xview scroll -1 pages
 }
-bind Listbox <<NextChar>> {
+bind Listbox <Right> {
     %W xview scroll 1 units
 }
-bind Listbox <<NextWord>> {
+bind Listbox <Control-Right> {
     %W xview scroll 1 pages
 }
 bind Listbox <Prior> {
@@ -107,10 +108,10 @@ bind Listbox <Control-Prior> {
 bind Listbox <Control-Next> {
     %W xview scroll 1 pages
 }
-bind Listbox <<LineStart>> {
+bind Listbox <Home> {
     %W xview moveto 0
 }
-bind Listbox <<LineEnd>> {
+bind Listbox <End> {
     %W xview moveto 1
 }
 bind Listbox <Control-Home> {
@@ -118,88 +119,59 @@ bind Listbox <Control-Home> {
     %W see 0
     %W selection clear 0 end
     %W selection set 0
-    tk::FireListboxSelectEvent %W
 }
-bind Listbox <Control-Shift-Home> {
-    tk::ListboxDataExtend %W 0
+bind Listbox <Shift-Control-Home> {
+    tkListboxDataExtend %W 0
 }
 bind Listbox <Control-End> {
     %W activate end
     %W see end
     %W selection clear 0 end
     %W selection set end
-    tk::FireListboxSelectEvent %W
 }
-bind Listbox <Control-Shift-End> {
-    tk::ListboxDataExtend %W [%W index end]
+bind Listbox <Shift-Control-End> {
+    tkListboxDataExtend %W end
 }
-bind Listbox <<Copy>> {
-    if {[selection own -displayof %W] eq "%W"} {
+bind Listbox <F16> {
+    if {[selection own -displayof %W] == "%W"} {
 	clipboard clear -displayof %W
 	clipboard append -displayof %W [selection get -displayof %W]
     }
 }
 bind Listbox <space> {
-    tk::ListboxBeginSelect %W [%W index active]
-}
-bind Listbox <<Invoke>> {
-    tk::ListboxBeginSelect %W [%W index active]
+    tkListboxBeginSelect %W [%W index active]
 }
 bind Listbox <Select> {
-    tk::ListboxBeginSelect %W [%W index active]
+    tkListboxBeginSelect %W [%W index active]
 }
 bind Listbox <Control-Shift-space> {
-    tk::ListboxBeginExtend %W [%W index active]
+    tkListboxBeginExtend %W [%W index active]
 }
 bind Listbox <Shift-Select> {
-    tk::ListboxBeginExtend %W [%W index active]
+    tkListboxBeginExtend %W [%W index active]
 }
 bind Listbox <Escape> {
-    tk::ListboxCancel %W
+    tkListboxCancel %W
 }
-bind Listbox <<SelectAll>> {
-    tk::ListboxSelectAll %W
+bind Listbox <Control-slash> {
+    tkListboxSelectAll %W
 }
-bind Listbox <<SelectNone>> {
-    if {[%W cget -selectmode] ne "browse"} {
+bind Listbox <Control-backslash> {
+    if {[%W cget -selectmode] != "browse"} {
 	%W selection clear 0 end
-	tk::FireListboxSelectEvent %W
     }
 }
 
 # Additional Tk bindings that aren't part of the Motif look and feel:
 
-bind Listbox <Button-2> {
+bind Listbox <2> {
     %W scan mark %x %y
 }
 bind Listbox <B2-Motion> {
     %W scan dragto %x %y
 }
-bind Listbox <MouseWheel> {
-    tk::MouseWheel %W y %D -40.0 units
-}
-bind Listbox <Option-MouseWheel> {
-    tk::MouseWheel %W y %D -12.0 units
-}
-bind Listbox <Shift-MouseWheel> {
-    tk::MouseWheel %W x %D -40.0 units
-}
-bind Listbox <Shift-Option-MouseWheel> {
-    tk::MouseWheel %W x %D -12.0 units
-}
-bind Listbox <TouchpadScroll> {
-    if {%# %% 5 == 0} {
-	lassign [tk::PreciseScrollDeltas %D] tk::Priv(deltaX) tk::Priv(deltaY)
-	if {$tk::Priv(deltaX) != 0} {
-	    %W xview scroll [expr {-$tk::Priv(deltaX)}] units
-	}
-	if {$tk::Priv(deltaY) != 0} {
-	    %W yview scroll [expr {-$tk::Priv(deltaY)}] units
-	}
-    }
-}
 
-# ::tk::ListboxBeginSelect --
+# tkListboxBeginSelect --
 #
 # This procedure is typically invoked on button-1 presses.  It begins
 # the process of making a selection in the listbox.  Its exact behavior
@@ -211,10 +183,10 @@ bind Listbox <TouchpadScroll> {
 # el -		The element for the selection operation (typically the
 #		one under the pointer).  Must be in numerical form.
 
-proc ::tk::ListboxBeginSelect {w el {focus 1}} {
-    variable ::tk::Priv
-    if {[$w cget -selectmode] eq "multiple"} {
-	if {[$w selection includes $el]} {
+proc tkListboxBeginSelect {w el} {
+    global tkPriv
+    if {[$w cget -selectmode]  == "multiple"} {
+	if [$w selection includes $el] {
 	    $w selection clear $el
 	} else {
 	    $w selection set $el
@@ -223,17 +195,12 @@ proc ::tk::ListboxBeginSelect {w el {focus 1}} {
 	$w selection clear 0 end
 	$w selection set $el
 	$w selection anchor $el
-	set Priv(listboxSelection) {}
-	set Priv(listboxPrev) $el
-    }
-    tk::FireListboxSelectEvent $w
-    # check existence as ListboxSelect may destroy us
-    if {$focus && [winfo exists $w] && [$w cget -state] eq "normal"} {
-	focus $w
+	set tkPriv(listboxSelection) {}
+	set tkPriv(listboxPrev) $el
     }
 }
 
-# ::tk::ListboxMotion --
+# tkListboxMotion --
 #
 # This procedure is called to process mouse motion events while
 # button 1 is down.  It may move or extend the selection, depending
@@ -243,9 +210,9 @@ proc ::tk::ListboxBeginSelect {w el {focus 1}} {
 # w -		The listbox widget.
 # el -		The element under the pointer (must be a number).
 
-proc ::tk::ListboxMotion {w el} {
-    variable ::tk::Priv
-    if {$el == $Priv(listboxPrev)} {
+proc tkListboxMotion {w el} {
+    global tkPriv
+    if {$el == $tkPriv(listboxPrev)} {
 	return
     }
     set anchor [$w index anchor]
@@ -253,44 +220,35 @@ proc ::tk::ListboxMotion {w el} {
 	browse {
 	    $w selection clear 0 end
 	    $w selection set $el
-	    set Priv(listboxPrev) $el
-	    tk::FireListboxSelectEvent $w
+	    set tkPriv(listboxPrev) $el
 	}
 	extended {
-	    set i $Priv(listboxPrev)
-	    if {$i < 0} {
-		set i $el
-		$w selection set $el
-	    }
-	    if {[$w selection includes anchor]} {
+	    set i $tkPriv(listboxPrev)
+	    if [$w selection includes anchor] {
 		$w selection clear $i $el
 		$w selection set anchor $el
 	    } else {
 		$w selection clear $i $el
 		$w selection clear anchor $el
 	    }
-	    if {![info exists Priv(listboxSelection)]} {
-		set Priv(listboxSelection) [$w curselection]
-	    }
 	    while {($i < $el) && ($i < $anchor)} {
-		if {$i in $Priv(listboxSelection)} {
+		if {[lsearch $tkPriv(listboxSelection) $i] >= 0} {
 		    $w selection set $i
 		}
 		incr i
 	    }
 	    while {($i > $el) && ($i > $anchor)} {
-		if {$i in $Priv(listboxSelection)} {
+		if {[lsearch $tkPriv(listboxSelection) $i] >= 0} {
 		    $w selection set $i
 		}
 		incr i -1
 	    }
-	    set Priv(listboxPrev) $el
-	    tk::FireListboxSelectEvent $w
+	    set tkPriv(listboxPrev) $el
 	}
     }
 }
 
-# ::tk::ListboxBeginExtend --
+# tkListboxBeginExtend --
 #
 # This procedure is typically invoked on shift-button-1 presses.  It
 # begins the process of extending a selection in the listbox.  Its
@@ -302,18 +260,14 @@ proc ::tk::ListboxMotion {w el} {
 # el -		The element for the selection operation (typically the
 #		one under the pointer).  Must be in numerical form.
 
-proc ::tk::ListboxBeginExtend {w el} {
-    if {[$w cget -selectmode] eq "extended"} {
-	if {[$w selection includes anchor]} {
-	    ListboxMotion $w $el
-	} else {
-	    # No selection yet; simulate the begin-select operation.
-	    ListboxBeginSelect $w $el
-	}
+proc tkListboxBeginExtend {w el} {
+    if {([$w cget -selectmode] == "extended")
+	    && [$w selection includes anchor]} {
+	tkListboxMotion $w $el
     }
 }
 
-# ::tk::ListboxBeginToggle --
+# tkListboxBeginToggle --
 #
 # This procedure is typically invoked on control-button-1 presses.  It
 # begins the process of toggling a selection in the listbox.  Its
@@ -325,22 +279,21 @@ proc ::tk::ListboxBeginExtend {w el} {
 # el -		The element for the selection operation (typically the
 #		one under the pointer).  Must be in numerical form.
 
-proc ::tk::ListboxBeginToggle {w el} {
-    variable ::tk::Priv
-    if {[$w cget -selectmode] eq "extended"} {
-	set Priv(listboxSelection) [$w curselection]
-	set Priv(listboxPrev) $el
+proc tkListboxBeginToggle {w el} {
+    global tkPriv
+    if {[$w cget -selectmode] == "extended"} {
+	set tkPriv(listboxSelection) [$w curselection]
+	set tkPriv(listboxPrev) $el
 	$w selection anchor $el
-	if {[$w selection includes $el]} {
+	if [$w selection includes $el] {
 	    $w selection clear $el
 	} else {
 	    $w selection set $el
 	}
-	tk::FireListboxSelectEvent $w
     }
 }
 
-# ::tk::ListboxAutoScan --
+# tkListboxAutoScan --
 # This procedure is invoked when the mouse leaves an entry window
 # with button 1 down.  It scrolls the window up, down, left, or
 # right, depending on where the mouse left the window, and reschedules
@@ -350,11 +303,10 @@ proc ::tk::ListboxBeginToggle {w el} {
 # Arguments:
 # w -		The entry window.
 
-proc ::tk::ListboxAutoScan {w} {
-    variable ::tk::Priv
-    if {![winfo exists $w]} return
-    set x $Priv(x)
-    set y $Priv(y)
+proc tkListboxAutoScan {w} {
+    global tkPriv
+    set x $tkPriv(x)
+    set y $tkPriv(y)
     if {$y >= [winfo height $w]} {
 	$w yview scroll 1 units
     } elseif {$y < 0} {
@@ -366,11 +318,11 @@ proc ::tk::ListboxAutoScan {w} {
     } else {
 	return
     }
-    ListboxMotion $w [$w index @$x,$y]
-    set Priv(afterId) [after 50 [list tk::ListboxAutoScan $w]]
+    tkListboxMotion $w [$w index @$x,$y]
+    set tkPriv(afterId) [after 50 tkListboxAutoScan $w]
 }
 
-# ::tk::ListboxUpDown --
+# tkListboxUpDown --
 #
 # Moves the location cursor (active element) up or down by one element,
 # and changes the selection if we're in browse or extended selection
@@ -380,28 +332,26 @@ proc ::tk::ListboxAutoScan {w} {
 # w -		The listbox widget.
 # amount -	+1 to move down one item, -1 to move back one item.
 
-proc ::tk::ListboxUpDown {w amount} {
-    variable ::tk::Priv
-    $w activate [expr {[$w index active] + $amount}]
+proc tkListboxUpDown {w amount} {
+    global tkPriv
+    $w activate [expr [$w index active] + $amount]
     $w see active
     switch [$w cget -selectmode] {
 	browse {
 	    $w selection clear 0 end
 	    $w selection set active
-	    tk::FireListboxSelectEvent $w
 	}
 	extended {
 	    $w selection clear 0 end
 	    $w selection set active
 	    $w selection anchor active
-	    set Priv(listboxPrev) [$w index active]
-	    set Priv(listboxSelection) {}
-	    tk::FireListboxSelectEvent $w
+	    set tkPriv(listboxPrev) [$w index active]
+	    set tkPriv(listboxSelection) {}
 	}
     }
 }
 
-# ::tk::ListboxExtendUpDown --
+# tkListboxExtendUpDown --
 #
 # Does nothing unless we're in extended selection mode;  in this
 # case it moves the location cursor (active element) up or down by
@@ -411,22 +361,16 @@ proc ::tk::ListboxUpDown {w amount} {
 # w -		The listbox widget.
 # amount -	+1 to move down one item, -1 to move back one item.
 
-proc ::tk::ListboxExtendUpDown {w amount} {
-    variable ::tk::Priv
-    if {[$w cget -selectmode] ne "extended"} {
+proc tkListboxExtendUpDown {w amount} {
+    if {[$w cget -selectmode] != "extended"} {
 	return
     }
-    set active [$w index active]
-    if {![info exists Priv(listboxSelection)]} {
-	$w selection set $active
-	set Priv(listboxSelection) [$w curselection]
-    }
-    $w activate [expr {$active + $amount}]
+    $w activate [expr [$w index active] + $amount]
     $w see active
-    ListboxMotion $w [$w index active]
+    tkListboxMotion $w [$w index active]
 }
 
-# ::tk::ListboxDataExtend
+# tkListboxDataExtend
 #
 # This procedure is called for key-presses such as Shift-KEndData.
 # If the selection mode isn't multiple or extend then it does nothing.
@@ -437,21 +381,21 @@ proc ::tk::ListboxExtendUpDown {w amount} {
 # w -		The listbox widget.
 # el -		An integer element number.
 
-proc ::tk::ListboxDataExtend {w el} {
+proc tkListboxDataExtend {w el} {
     set mode [$w cget -selectmode]
-    if {$mode eq "extended"} {
+    if {$mode == "extended"} {
 	$w activate $el
 	$w see $el
-	if {[$w selection includes anchor]} {
-	    ListboxMotion $w $el
+        if [$w selection includes anchor] {
+	    tkListboxMotion $w $el
 	}
-    } elseif {$mode eq "multiple"} {
+    } elseif {$mode == "multiple"} {
 	$w activate $el
 	$w see $el
     }
 }
 
-# ::tk::ListboxCancel
+# tkListboxCancel
 #
 # This procedure is invoked to cancel an extended selection in
 # progress.  If there is an extended selection in progress, it
@@ -461,17 +405,13 @@ proc ::tk::ListboxDataExtend {w el} {
 # Arguments:
 # w -		The listbox widget.
 
-proc ::tk::ListboxCancel w {
-    variable ::tk::Priv
-    if {[$w cget -selectmode] ne "extended"} {
+proc tkListboxCancel w {
+    global tkPriv
+    if {[$w cget -selectmode] != "extended"} {
 	return
     }
     set first [$w index anchor]
-    set last $Priv(listboxPrev)
-    if {$last < 0} {
-	# Not actually doing any selection right now
-	return
-    }
+    set last $tkPriv(listboxPrev)
     if {$first > $last} {
 	set tmp $first
 	set first $last
@@ -479,15 +419,14 @@ proc ::tk::ListboxCancel w {
     }
     $w selection clear $first $last
     while {$first <= $last} {
-	if {$first in $Priv(listboxSelection)} {
+	if {[lsearch $tkPriv(listboxSelection) $first] >= 0} {
 	    $w selection set $first
 	}
 	incr first
     }
-    tk::FireListboxSelectEvent $w
 }
 
-# ::tk::ListboxSelectAll
+# tkListboxSelectAll
 #
 # This procedure is invoked to handle the "select all" operation.
 # For single and browse mode, it just selects the active element.
@@ -496,27 +435,12 @@ proc ::tk::ListboxCancel w {
 # Arguments:
 # w -		The listbox widget.
 
-proc ::tk::ListboxSelectAll w {
+proc tkListboxSelectAll w {
     set mode [$w cget -selectmode]
-    if {$mode eq "single" || $mode eq "browse"} {
+    if {($mode == "single") || ($mode == "browse")} {
 	$w selection clear 0 end
 	$w selection set active
     } else {
 	$w selection set 0 end
     }
-    tk::FireListboxSelectEvent $w
-}
-
-# ::tk::FireListboxSelectEvent
-#
-# Fire the <<ListboxSelect>> event if the listbox is not in disabled
-# state.
-#
-# Arguments:
-# w -		The listbox widget.
-
-proc ::tk::FireListboxSelectEvent w {
-    if {[$w cget -state] eq "normal"} {
-	event generate $w <<ListboxSelect>>
-    }
 }
