@@ -1,5 +1,7 @@
 # This file creates a visual test for button layout.  It is part of
 # the Tk visual test suite, which is invoked via the "visual" script.
+#
+# @(#) butGeom.tcl 1.1 94/08/10 15:49:40
 
 catch {destroy .t}
 toplevel .t
@@ -54,7 +56,7 @@ place .t.anchor-s -in .t.control.left.f -relx 0.333 -relwidth 0.333 \
 place .t.anchor-se -in .t.control.left.f -relx 0.666 -relwidth 0.333 \
 	-rely 0.666 -relheight 0.333
 
-set justify center
+set justify left
 radiobutton .t.justify-left -text "Justify Left" -relief flat \
 	-command "config -justify left" -variable justify \
 	-value left
@@ -111,16 +113,3 @@ proc config {option value} {
 	$w configure $option $value
     }
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
