@@ -13,7 +13,7 @@
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  */
 
-static char sccsid[] = "@(#) tkMenu.c 1.93 95/07/22 16:05:23";
+static char sccsid[] = "@(#) tkMenu.c 1.94 95/08/26 17:21:13";
 
 #include "tkPort.h"
 #include "default.h"
@@ -1741,15 +1741,23 @@ DisplayMenu(clientData)
 		    bgBorder, menuPtr->borderWidth, mePtr->y,
 		    Tk_Width(tkwin) - 2*menuPtr->borderWidth, mePtr->height,
 		    menuPtr->activeBorderWidth, TK_RELIEF_RAISED);
-	    gc = mePtr->activeGC;
-	    if (gc == NULL) {
-		gc = menuPtr->activeGC;
-	    }
 	} else {
 	    Tk_Fill3DRectangle(menuPtr->tkwin, Tk_WindowId(tkwin),
 		    bgBorder, menuPtr->borderWidth, mePtr->y,
 		    Tk_Width(tkwin) - 2*menuPtr->borderWidth, mePtr->height,
 		    0, TK_RELIEF_FLAT);
+	}
+
+	/*
+	 * Choose the gc for drawing the foreground part of the entry.
+	 */
+
+	if ((mePtr->state == tkActiveUid) && !strictMotif) {
+	    gc = mePtr->activeGC;
+	    if (gc == NULL) {
+		gc = menuPtr->activeGC;
+	    }
+	} else {
 	    if ((mePtr->state == tkDisabledUid)
 		    && (menuPtr->disabledFg != NULL)) {
 		gc = mePtr->disabledGC;
