@@ -18,7 +18,7 @@
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  */
 
-static char sccsid[] = "@(#) tkScale.c 1.72 95/06/09 08:20:04";
+static char sccsid[] = "@(#) tkScale.c 1.73 95/11/25 22:47:16";
 
 #include "tkPort.h"
 #include "default.h"
@@ -722,7 +722,7 @@ ConfigureScale(interp, scalePtr, argc, argv, flags)
 	if (stringValue != NULL) {
 	    value = strtod(stringValue, &end);
 	    if ((end != stringValue) && (*end == 0)) {
-		scalePtr->value = value;
+		scalePtr->value = RoundToResolution(scalePtr, value);
 	    }
 	}
 	Tcl_TraceVar(interp, scalePtr->varName,
@@ -1953,20 +1953,23 @@ RoundToResolution(scalePtr, value)
     Scale *scalePtr;		/* Information about scale widget. */
     double value;		/* Value to round. */
 {
-    double rem;
+    double rem, new;
 
     if (scalePtr->resolution <= 0) {
 	return value;
     }
-    rem = fmod(value, scalePtr->resolution);
+    new = scalePtr->resolution * floor(value/scalePtr->resolution);
+    rem = value - new;
     if (rem < 0) {
-	rem = scalePtr->resolution + rem;
+	if (rem <= -scalePtr->resolution/2) {
+	    new -= scalePtr->resolution;
+	}
+    } else {
+	if (rem >= scalePtr->resolution/2) {
+	    new += scalePtr->resolution;
+	}
     }
-    value -= rem;
-    if (rem >= scalePtr->resolution/2) {
-	value += scalePtr->resolution;
-    }
-    return value;
+    return new;
 }
 
 /*
@@ -2033,7 +2036,7 @@ ScaleVarProc(clientData, interp, name1, name2, flags)
 	if ((end == stringValue) || (*end != 0)) {
 	    result = "can't assign non-numeric value to scale variable";
 	} else {
-	    scalePtr->value = value;
+	    scalePtr->value = RoundToResolution(scalePtr, value);
 	}
 
 	/*
